@@ -89,6 +89,15 @@ def file_contents( ) :
     return( db_filecontents )
 
 
+def blob_set( d ) :
+    blob = s_util.decompress( d )
+    rewrite( blob )
+
+def blob_get( ) :
+    db_filecontents = file_contents( )
+    blob = s_util.compress( db_filecontents )
+    return( blob )
+
 def rewrite( payload ) :
 
     #rev = 1
@@ -105,6 +114,15 @@ def rewrite( payload ) :
 
     reconnect( )
 
+    ################################################################
+
+    ver_sapi = sys_read( "ver_sapi" )
+    ver_db = sys_read( "ver_db" )
+
+    if( ver_sapi != s_config.get_key( "/config/version" ) ) :
+        s_log.write( "WARNING,VER_SAPI MISMATCH," + ver_sapi + "!=" + s_config.get_key( "/config/version" ) + "," + ver_db )
+
+
     #sys_update("rev",rev)
     #s_log.write("REV rewrite "+str(rev))
 
@@ -211,10 +229,12 @@ def init_schema( ) :
     sql_execute( "CREATE TABLE sys ( sn text UNIQUE , sv text )" )
     sql_execute( "CREATE INDEX index_sys ON sys ( sn )" )
 
-    sys_create( "ver" , 1 )
+    sys_create( "ver_db" , "1.0" )
+    sys_create( "ver_sapi" , s_config.get_key( "/config/version" ) )
     sys_create( "serial" , "ODS042e1919c5bd8f41cd8e1a2b8e455dd8f6fb00df0c3916d1137047a7aafc4c42" )
-    sys_create( "rev" , 1 )
     sys_create( "motto" , "HORAS NON NUMERO NISI SERENAS" )
+    sys_create( "rev" , 1 )
+    sys_create( "tcreate" , time.time( ) )
 
     ################################################################
 
@@ -439,14 +459,6 @@ def meta_delete( mn ) :
 def meta_deleteall( ) :
     table_truncate( "meta" )
 
-
-def meta_checkupdefault( ) :
-    mn = "_default_5800b137d"
-    t = meta_read( mn )
-    if not t :
-        meta_setdefault( )
-
-
 def meta_createorupdate( mn , mv ) :
     t = meta_read( mn )
     if t :
@@ -454,28 +466,6 @@ def meta_createorupdate( mn , mv ) :
     else :
         meta_create( mn , mv )
 
-
-
-def meta_setdefault( mv_in = False ) :
-    # _default_5800b137d
-
-    d = { "_time" : time.time( ) }
-
-    if mv_in :
-        d.update( mv_in )
-
-    mn = "_default_5800b137d"
-    meta_createorupdate( mn , d )
-    return( True )
-
-def meta_getdefault( ) :
-    # _default_5800b137d
-    mn = "_default_5800b137d"
-    mv = meta_read( mn )
-    return( mv )
-
-
-
 ####################################################################
 
 def args_create( av ) :
@@ -483,7 +473,7 @@ def args_create( av ) :
     sql = "INSERT INTO args ( aid , av ) VALUES ( ? , ? )"
     data = ( None , av )
     sql_execute_parameters( sql , data )
-    return(True)
+    return( True )
 
 def args_count( ) :
     count = table_rowcount( "args" )
@@ -537,7 +527,7 @@ def stdio_readformatted( sk ) :
     for r in rows:
         #buff = buff + str( r["sv"],"utf-8")+"\n"
         buff = buff + r["sv"]+"\n"
-    return(buff)
+    return( buff )
 
 def stdio_readall( ) :
     rows = table_readall( "stdio" )
@@ -617,7 +607,6 @@ def files_readall( ) :
 
 # def files_update !!!
 # Delete current path and create a new one?!?!?!
-
 def files_update( fp ) :
     files_delete( fp ) 
     files_create( fp ) 
@@ -647,38 +636,62 @@ def files_dict2json( fp , fdict ) :
 
     return( True )
 
-def files_get_defaultdata( ) :
-    f = files_read( "./local_sapiserver_default_5800b137d.json" )
+def files_getcontent( fp ) :
+    f = files_read( fp )
+    if not f:
+        s_log.write( "False files_getcontent" )
+        return( False )
+    return( f[ "fc" ] )
+
+def files_write( fp ) :
+    with open( fp , "w" , 1 ) as f :
+        f.write( files_getcontent( fp ) )
+
+
+########################
+def files_defmeta_set( data ) :
+
+    files_delete( "./local_defmeta_5800b137d.json" )
+
+    flag = files_dict2json( "./local_defmeta_5800b137d.json" , data )
+    if not flag :
+        s_log.write( "False files_defmeta_set" )
+        return( False )
+
+    return( True )
+
+def files_defmeta_get( ) :
+    f = files_read( "./local_defmeta_5800b137d.json" )
     if not f :
+        s_log.write( "False files_defmeta_set files_read" )
         return( False )
     d = json.loads( f[ "fc" ] )
     return( d )
 
-def files_set_defaultdata( data ) :
+def files_defmeta_write( ) :
+    files_write( "./local_defmeta_5800b137d.json" )
+########################
+def files_defdata_set( data ) :
 
-    if( tablerow_exists( "files" , "where fp='./local_sapiserver_default_5800b137d.json'" ) ) :
-        files_delete("./local_sapiserver_default_5800b137d.json")
+    files_delete( "./local_defdata_5800b137d.json" )
 
-
-    flag = files_dict2json( "./local_sapiserver_default_5800b137d.json" , data )
+    flag = files_dict2json( "./local_defdata_5800b137d.json" , data )
     if not flag :
-        s_log.write("False files_set_defaultdata")
-        return(False)
+        s_log.write( "False files_defdata_set" )
+        return( False )
 
-    return(True)
-
-def files_getcontent( fp ) :
-    f = files_read( fp )
-    if not f:
-        s_log.write("False files_getcontent")
-        return(False)
-    return(f["fc"])
-
-def files_write_defaultdata( ) :
-    with open( "./local_sapiserver_default_5800b137d.json" , "w" , 1 ) as f :
-        f.write( files_getcontent( "./local_sapiserver_default_5800b137d.json" ) )
+    return( True )
 
+def files_defdata_get( ) :
+    f = files_read( "./local_defdata_5800b137d.json" )
+    if not f :
+        s_log.write( "False files_defdata_get files_read" )
+        return( False )
+    d = json.loads( f[ "fc" ] )
+    return( d )
 
+def files_defdata_write( ) :
+    files_write( "./local_defdata_5800b137d.json" )
 
 ####################################################################
 
