@@ -35,6 +35,8 @@ log_traceid = False
 
 def init( ) :
 
+    #if(not s_config.key_is_yes("log")): return(False)
+
     global log_traceid
     global log_filepath
 
@@ -63,7 +65,9 @@ def default_json( t ) :
 
 def write( msg_raw ) :
 
+    #if not init( ): return
     init( )
+    if(s_config.key_is_no("sys/log")): return
 
     msg = msg_raw
 
