@@ -29,8 +29,6 @@ session = requests.Session( )
 
 #####################################################################
 
-# FIXME TODO - Should really check all the way through to OMNIBUS
-
 check_connectivity_done = False
 
 def check_connectivity( ) :
@@ -56,15 +54,9 @@ def check_connectivity( ) :
         s_log.write( "False endpoint_url scheme " + endpoint_url )
         return( False )
 
-
-    #s_log.write( endpoint_parseurl.scheme)
-    #s_log.write( endpoint_parseurl.hostname )
-    #s_log.write( endpoint_parseurl.port )
-
     ################################################################
 
     if( s_util.is_ip( endpoint_parseurl.hostname ) ) :
-        #s_log.write("check_connectivity s_util.is_ip")
         s_config.set_key_alt( "endpoint/sslverify" , "no" )
     
     ################################################################
@@ -75,10 +67,8 @@ def check_connectivity( ) :
 
     ################################################################
 
-    #s_log.write( endpoint_parseurl.hostname )
-    #s_log.write( endpoint_parseurl.port )
-
     if( s_config.get_key( "endpoint/skipnetworkcheck1" ) != "yes" ) : 
+
         try :
 
             host = socket.gethostbyname( endpoint_parseurl.hostname ) 
@@ -89,21 +79,9 @@ def check_connectivity( ) :
             s_log.write( "False check_connectivity 1" )
             flag_networkok = False
 
-
     ################################################################
 
-    headers =   {
-                    "User-Agent" : "sapiadapter" ,
-                    "X-Omni-Authorization" : s_config.get_key( "endpoint/token" ) ,
-                    "X-Omni-Action": "mwget" ,
-                }
-
-    endpoint_host = s_config.get_key( "endpoint/host" )
-
-    if endpoint_host != None and endpoint_host != "" :
-        headers[ "Host" ] = endpoint_host
-
-    if( flag_networkok and get_request_response( headers ) == False ) :
+    if( flag_networkok and get_request_response( ) == False ) :
         s_log.write( "False check_connectivity 2" )
         flag_networkok = False
 
@@ -115,40 +93,28 @@ def check_connectivity( ) :
         return( True )
 
     endpoint_host =  s_config.get_key( "endpoint/host" , "HOST_NOT_SET")
-    s_log.write( endpoint_parseurl.hostname + "," + endpoint_parseurl.hostname + "," + str( endpoint_url_port ) + "," + endpoint_host )
+    s_log.write( endpoint_parseurl.hostname + "," + str( endpoint_url_port ) + "," + endpoint_host )
+
+    if( ( endpoint_url_port != 443 ) or ( endpoint_url_port != 10443 ) ) :
+        s_log.write( "maybe endpoint_url_port smells fishy..." )
 
     return( False )
 
 #####################################################################
 
-
 def job_request( ) :
 
     if( not s_util.ready( ) ) :
         s_log.write( "NOT READY" )
         return( False )
 
-    db_filecontents = s_db.file_contents( )
+    #####################################################################
 
-    payload = gzip.compress( db_filecontents  )
-
-    mw = mw_get( )
-    if( not mw ) : return( False )
+    payload = s_db.blob_get( )
 
     #####################################################################
 
-    headers =   {
-                    "User-Agent" : "sapiadapter" ,
-                    "X-Omni-Mw": mw ,
-                    "X-Omni-Authorization": s_config.get_key( "endpoint/token" ) ,
-                    "X-Omni-Action": "job_request" ,
-                }
-
-    endpoint_host = s_config.get_key( "endpoint/host" )
-    if endpoint_host != None and endpoint_host != "" :
-        headers[ "Host" ] = endpoint_host
-
-    #s_log.write( headers )
+    headers = { "X-Omni-Action": "job_request" }
 
     res = get_request_response( headers , payload )
 
@@ -168,15 +134,27 @@ def job_request( ) :
         s_log.write( "X-Omni-Jid!=67" )
         return( False )
 
+    #####################################################################
+
     jid = res.headers[ "X-Omni-Jid" ]
 
     s_log.write( "job_request [" + jid + "]" )
 
-    return( jid )
+    s_config.set_key( "jid" , jid )
+
+    #s_db.meta_jid_create( jid )
+
+    return( True )
 
 
 def job_responsewait( jid , timeout = 60 ) :
 
+    if( not s_util.ready( ) ) :
+        s_log.write( "NOT READY" )
+        return( False )
+        
+    #####################################################################
+
     s_log.write( "job_wait " + str( timeout ) )
     
     time_start = time.time( )
@@ -190,44 +168,27 @@ def job_responsewait( jid , timeout = 60 ) :
 
 def job_response( jid ) :
 
-    #s_db.setup( )
-
-    #time.sleep(1)
-
-    #s_db.reset( )
-
+    if( not s_util.ready( ) ) :
+        s_log.write( "NOT READY" )
+        return( False )
+        
     #####################################################################
 
-    mw = mw_get( )
-    if( not mw ) : return( False )
-
-    #####################################################################
-
-    endpoint_host = s_config.get_key( "endpoint/host" )
-    endpoint_token = s_config.get_key( "endpoint/token" )
-
     headers =   {
-                    "User-Agent" : "sapiadapter" ,
-                    "X-Omni-Mw": mw ,
-                    "X-Omni-Authorization": endpoint_token ,
-                    "X-Omni-Action": "job_response" ,
-                    "X-Omni-Jid": jid ,
+                    "X-Omni-Action" : "job_response" ,
+                    "X-Omni-Jid" : jid ,
                 }
 
-    if endpoint_host != None  and endpoint_host != "" :
-        headers[ "Host" ] = endpoint_host
-
-    #s_log.write( headers )
-
     res = get_request_response( headers )
 
+    #####################################################################
+
     if( res == False ) :
         s_log.write( "res??" )
         return( False )
 
     #s_log.write( str(res.headers ) )
 
-
     if( not "X-Omni-State" in res.headers ) :
         s_log.write( "Not found X-Omni-State" )
         return( False )
@@ -236,49 +197,24 @@ def job_response( jid ) :
         s_log.write( "job_response !=Done [" + jid + "]" )
         return( None )
 
-
-    #b1 = res.content[ -4: ].hex()
-    #s_log.write("HEX "+b1)
-
-    payload = gzip.decompress( res.content )
-
-    #s_log.write(hex(len(payload)))
-
-    s_db.rewrite( payload )
+    s_db.blob_set( res.content )
 
     return( True )
 
+####################################################################
 
-# FIXME TODO feel it could be improved
-job_id = False
 def job_get( ) :
 
-    global job_id
-
-    job_id = False
-
     if( not s_util.ready( ) ) :
         s_log.write( "NOT READY" )
         return( False )
 
-    mw = mw_get( )
-    if( not mw ) : return( False )
-
     #####################################################################
 
-    endpoint_host = s_config.get_key( "endpoint/host" )
-    endpoint_token = s_config.get_key( "endpoint/token" )
-
     headers =   {
-                    "User-Agent" : "sapiadapter" ,
-                    "X-Omni-Mw": mw ,
-                    "X-Omni-Authorization": endpoint_token ,
                     "X-Omni-Action": "job_get" ,
                 }
 
-    if endpoint_host != None  and endpoint_host != "" :
-        headers[ "Host" ] = endpoint_host
-
     #s_log.write( headers )
 
     res = get_request_response( headers )
@@ -306,19 +242,23 @@ def job_get( ) :
         context_json = s_util.base64_decode( res.headers[ "X-Omni-Context" ] )
         #s_db.meta_create( "_server_getjob_context_json" , context_json ) 
 
-    #if( "X-Omni-Jid" in res.headers ) :
-    job_id=res.headers[ "X-Omni-Jid" ]
-    s_db.meta_create( "_jid" , job_id ) 
+    job_id = res.headers[ "X-Omni-Jid" ]
+    s_config.set_key("jid", job_id ) 
     s_log.write( "job_get [" + job_id + "]" )
 
     return( True )
 
-def job_set( jid = False ) :
+def job_set( ) :
 
-    if not jid :
-        jid = job_id
+    if( not s_util.ready( ) ) :
+        s_log.write( "NOT READY" )
+        return( False )
 
-    s_db.meta_checkupdefault( )
+    #####################################################################
+
+    jid = s_config.get_key("jid")
+
+    #s_db.meta_checkupdefault( )
 
     s_db.sys_rev_inc( )
 
@@ -330,26 +270,11 @@ def job_set( jid = False ) :
 
     #####################################################################
 
-    mw = mw_get( )
-    if( not mw ) : return( False )
-
-    #####################################################################
-
-    endpoint_host = s_config.get_key( "endpoint/host" )
-    endpoint_token = s_config.get_key( "endpoint/token" )
-
     headers =   {
-                    "User-Agent" : "sapiadapter" ,
-                    "X-Omni-Mw": mw ,
-                    "X-Omni-Authorization": endpoint_token ,
                     "X-Omni-Action": "job_set" ,
                     "X-Omni-Jid": jid ,
-
                 }
 
-    if endpoint_host != None  and endpoint_host != "" :
-        headers[ "Host" ] = endpoint_host
-
     #s_log.write( headers )
 
     res = get_request_response( headers , payload )
@@ -369,7 +294,6 @@ def job_set( jid = False ) :
 
 #####################################################################
 
-
 def mw_get( ) :
     mw1 = get_mw( )
     if( mw1 == False ) :
@@ -383,15 +307,9 @@ def mw_get( ) :
 def get_mw( ) :
 
     headers =   {
-                    "User-Agent" : "sapiadapter" ,
-                    "X-Omni-Authorization" : s_config.get_key( "endpoint/token" ) ,
                     "X-Omni-Action": "mwget" ,
                 }
 
-    endpoint_host = s_config.get_key( "endpoint/host" )
-    if endpoint_host != None and endpoint_host != "" :
-        headers[ "Host" ] = endpoint_host
-
     #s_log.write( headers )
 
     res = get_request_response( headers )
@@ -424,12 +342,25 @@ def get_mw( ) :
 
 def get_request_response( request_headers = { }  , payload = "" ) :
 
-    # When empty headers the host must be set
-    if( request_headers == { } ) :
-        request_headers[ "User-Agent" ] = "sapiadapter" 
-        endpoint_host = s_config.get_key( "endpoint/host" )
-        if endpoint_host != None and endpoint_host != "" :
-            request_headers[ "Host" ] = endpoint_host
+    # Careful - don't want infinite recursion here!
+    if( "X-Omni-Action" in request_headers ) and ( request_headers[ "X-Omni-Action" ] != "mwget" ) :
+        if not "X-Omni-Mw" in request_headers :
+            mw = mw_get( )
+            if( not mw ) : return( False )
+            request_headers[ "X-Omni-Mw" ] = mw
+
+    ################################################################ 
+
+    if not "User-Agent" in request_headers :
+        request_headers[ "User-Agent" ] = "sapiadapter"
+    if not "X-Omni-Authorization" in request_headers :
+        request_headers[ "X-Omni-Authorization" ] = s_config.get_key( "endpoint/token" ) 
+
+    endpoint_host = s_config.get_key( "endpoint/host" )
+    if endpoint_host != None and endpoint_host != "" :
+        request_headers[ "Host" ] = endpoint_host
+
+    ################################################################ 
 
     request_headers[ "X-Omni-Traceid" ] = s_log.get_traceid( )   
 
@@ -441,7 +372,7 @@ def get_request_response( request_headers = { }  , payload = "" ) :
 
         endpoint_sslverify = True
     else :        
-        if endpoint_sslverify == "yes":
+        if endpoint_sslverify == "yes" :
             endpoint_sslverify = True
         else :
             endpoint_sslverify = False
@@ -459,8 +390,8 @@ def get_request_response( request_headers = { }  , payload = "" ) :
         s_log.write( "false endpoint_url" )
         return( False )
 
-    if(not endpoint_url.endswith("/")):
-        endpoint_url=endpoint_url+"/"
+    if( not endpoint_url.endswith( "/" ) ) :
+        endpoint_url = endpoint_url + "/"
 
     endpoint_url = endpoint_url + "api.html"
     #s_log.write(endpoint_url)
@@ -468,7 +399,7 @@ def get_request_response( request_headers = { }  , payload = "" ) :
     #####################################################################
 
     try :
-        #response = requests.post( endpoint_url , data = payload , headers = request_headers , timeout = endpoint_timeout , verify = endpoint_sslverify )
+
         response = session.post( endpoint_url , data = payload , headers = request_headers , timeout = endpoint_timeout , verify = endpoint_sslverify )
 
     except requests.exceptions.SSLError as e :
