@@ -22,6 +22,7 @@ import uuid
 import hashlib
 import base64
 import shutil
+import gzip
 
 from subprocess import Popen, PIPE
 
@@ -141,15 +142,19 @@ def ready( ) :
 
     return( True )
 
+####################################################################
+
 def gen_workingdirectory( ) :
     work_dir = wd = s_config.get_key( "sys/workspacedir" ) + "/" + uhash( "WOK" )
     return( work_dir )
 
+####################################################################
 
 def proc_setup( ) :
 
     work_dir = gen_workingdirectory( )
 
+    # FIXME TODO should be coming from config
     shutil.copytree( "/data/app/" , work_dir , ignore = shutil.ignore_patterns( ".git*" ) )
 
     os.chdir( work_dir )
@@ -161,9 +166,9 @@ def proc_setup( ) :
     proc_trackcurrentfiles( )
 
     ################
-    default_inputs =  s_db.meta_getdefault( )
-    s_db.files_set_defaultdata( default_inputs )
-    s_db.files_write_defaultdata( )
+    #default_inputs =  s_db.meta_getdefault( )
+    #s_db.files_set_defaultdata( default_inputs )
+    s_db.files_defmeta_write( )
     ################
 
     s_db.setup( ) 
@@ -184,12 +189,11 @@ def proc_trackcurrentfiles( ) :
 
     s_config.set_key( "sys/procfiles" , procfiles ) 
 
-
-
 def proc_run( ) :
 
     pargs = ""
 
+    # FIXME TODO filename should be coming from config
     process = Popen( [ "bash" , "_sapiserver_entrypoint_.sh" , pargs ] , stdout = PIPE , stderr = PIPE )
 
     stdout , stderr = process.communicate( )
@@ -214,8 +218,15 @@ def proc_storage( ) :
             fname = os.path.join( dirpath , filename )
             #fname=os.path.abspath(fname)
             #print(fname)
-            if fname in procfiles: continue
+            if fname in procfiles : continue
             #print(fname)
+
+
+            file_extension = Path( fname ).suffix
+
+            # FIXME TODO extensions (list of) should be coming from config
+            if(file_extension==".pyc"): continue
+
             if( not s_db.files_create( fname ) ) :
                 s_log.write( "ERROR files_create " + fname )
             #with open(fname) as myfile:
@@ -227,3 +238,12 @@ def proc_teardown( ) :
 
     os.chdir( s_config.get_key( "/config/cwd" ) )
 
+####################################################################
+
+def compress( d ) :
+    blob = gzip.compress( d )
+    return( blob )
+
+def decompress( d ) :
+    blob = gzip.decompress( d )
+    return( blob )
