@@ -17,7 +17,7 @@ from . import s_log , s_config , s_net , s_util , s_db , s_cleanup
 
 #####################################################################
 
-s_log.write( "    ####    ####    ####    ####\n" )
+#s_log.write( "    ####    ####    ####    ####\n" )
 
 #####################################################################
 
@@ -34,8 +34,11 @@ def ready( ) :
 def prexit( msg ) :
     s_util.printexit( msg )
 
-def defout( ) :
-    return( s_db.files_get_defaultdata( ) )
+def defdata( ) :
+    return( s_db.files_defdata_get( ) )
+
+def defmeta( ) :
+    return( s_db.files_defmeta_get( ) )
 
 def uptime( ) :
     return( s_util.uptime( ) )
@@ -43,6 +46,76 @@ def uptime( ) :
 def heartbeat( t = 60 ) :
     return( s_util.heartbeat( t ) )
 
+def server( ) :
+
+    s_log.write( "SERVER STARTED" )
+
+    while True :
+
+        heartbeat( )
+
+        #####################################################
+
+        try :
+            flag_jobget = s_net.job_get( )
+        except Exception as e :
+            s_util.printexception( )
+            #continue
+            prexit( "EXCEPTION job_get" )
+            #sys.exit( 99 )
+
+        #####################################################
+        
+        if flag_jobget == False :
+
+            print( "ERROR False job_get" )
+            continue
+            #sapi.prexit( "False job_get" )
+
+        if flag_jobget == None :
+            continue
+
+        #####################################################
+
+        defmeta = s_db.files_defmeta_get( )
+        if( "_ping_5800b137d" in defmeta ) :
+            #print(defmeta["_ping_5800b137d"])
+            t1 = defmeta["_ping_5800b137d"]
+            s_db.setup( )
+            defdata=["_ping_5800b137d"] 
+            defmeta = {
+                "_ping_5800b137d" : "." + t1
+            }
+            s_db.files_defdata_set( defdata )
+            s_db.files_defmeta_set( defmeta)
+            s_net.job_set( )
+            print( "OK PINGPONG" )
+            continue
+
+        #####################################################
+
+        s_util.proc_setup( )
+
+        #####################################################
+
+        s_util.proc_run( )
+
+        #####################################################
+
+        s_util.proc_storage( )
+        s_util.proc_teardown( )
+
+        #####################################################
+
+        s_net.job_set( )
+
+        #####################################################
+
+        print( "OK" )
+
+
+
+
 #####################################################################
 
 # DATA
@@ -67,7 +140,7 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    f = s_db.meta_setdefault( meta_inputs ) 
+    f = s_db.files_defmeta_set( meta_inputs ) 
 
     if( not f ) :
         s_log.write( "false meta_add " )
@@ -75,10 +148,14 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    jid = s_net.job_request( )
+    if not s_net.job_request( ) :
+        s_log.write( "false job_request" )
+        return( False )
 
     #####################################################################
 
+    jid = s_config.get_key( "jid" )
+
     if( jid == False ) :
         s_log.write( "false job_request jid" )
         return( False )
@@ -97,12 +174,10 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    #s_log.write(s_util.uptime())
-
     if( s_db.stdio_has_stderr( ) ) :
         s_log.write( "ERROR stdio_has_stderr " + s_db.stdio_get_stderr( ) )
         return( None )
 
     #####################################################################
 
-    return( s_db.meta_getdefault( ) )
+    return( True )
